"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.processBreedsOption = processBreedsOption;
exports.processBreedOption = processBreedOption;

var _axios = _interopRequireDefault(require("axios"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

const URL = "https://dog.ceo/api";

function processBreedsOption(_x) {
  return _processBreedsOption.apply(this, arguments);
}

function _processBreedsOption() {
  _processBreedsOption = _asyncToGenerator(function* (option) {
    if (!option) {
      return {
        fetched: false
      };
    }

    let fetched = false;
    let list = null;
    let images = null; // Fetch list of dog breeds

    if (option.list) {
      fetched = true;

      try {
        const listResponse = yield _axios.default.get(`${URL}/breeds/list/all`);
        list = listResponse.data.message;
      } catch (error) {
        throw new Error("Couldn't fetch list of all dog breeds.");
      }
    } // Fetch random dog images


    if (option.random && option.number !== 0) {
      fetched = true;
      let number = option.number;

      if (typeof number !== "number" || number < 0) {
        number = 1;
      }

      try {
        const _ref2 = yield _axios.default.get(`${URL}/breeds/image/random/${number}`),
              status = _ref2.status,
              imageData = _ref2.data;

        images = status === 404 ? [] : imageData.message;
      } catch (error) {
        throw new Error("Couldn't fetch random dog images.");
      }
    }

    return {
      fetched,
      list,
      images
    };
  });
  return _processBreedsOption.apply(this, arguments);
}

function processBreedOption(_x2) {
  return _processBreedOption.apply(this, arguments);
}

function _processBreedOption() {
  _processBreedOption = _asyncToGenerator(function* (option) {
    let fetched = false;
    let images = {};

    if (!option) {
      return {
        fetched,
        images
      };
    }

    if (typeof option === "string") {
      // option = name of a breed
      fetched = true;

      const _ref3 = yield fetchImageByBreed({
        name: option
      }),
            breedImages = _ref3.images;

      images[option] = breedImages;
    } else if (Array.isArray(option)) {
      fetched = true;
      /**
       * Has to do the {...number, ...breed} thing
       * because dog API doesn't allow fetching multiple random images
       * from a breed
       * -> We're adding number * Promise into promiseArr
       */

      const promiseArr = [];
      option.forEach(breed => {
        if (typeof breed === "string") {
          promiseArr.push(fetchImageByBreed({
            name: breed
          }));
        } else {
          if (!breed.random) {
            promiseArr.push(fetchImageByBreed({
              name: breed.name
            }));
          } else {
            Array.from(Array(breed.number), () => {
              promiseArr.push(fetchImageByBreed({
                name: breed.name,
                random: true
              }));
            });
          }
        }
      }); // Resolve all promises and turn into final object

      const results = yield Promise.all(promiseArr);
      images = results.reduce((a, v) => {
        if (a[v.name]) {
          a[v.name] = [...a[v.name], ...v.images];
        } else {
          a[v.name] = v.images;
        }

        return a;
      }, {});
    } else {
      throw new Error("option.breed must be a string or an array");
    }

    return {
      fetched,
      images
    };
  });
  return _processBreedOption.apply(this, arguments);
}

function fetchImageByBreed({
  name,
  random = false
}) {
  return new Promise(
  /*#__PURE__*/
  function () {
    var _ref = _asyncToGenerator(function* (resolve, reject) {
      const breed = name.includes(" ") ? name.split(" ").reverse().reduce((a, v) => `${a}-${v}`).toLowerCase() : name.toLowerCase();
      const returnObj = {};
      returnObj.name = name;
      let response;

      try {
        if (!random) {
          response = yield _axios.default.get(`${URL}/breed/${breed}/images`);
        } else {
          response = yield _axios.default.get(`${URL}/breed/${breed}/images/random`); // return axios.get(`${URL}/breed/${breed}/images/random`/${number})
        }
      } catch (error) {
        reject(new Error(`Couldn't fetch images of breed: ${name}`));
      }

      if (response.status === 404) {
        returnObj.images = [];
      } else {
        if (typeof response.data.message === "string") {
          returnObj.images = [response.data.message];
        } else {
          returnObj.images = response.data.message;
        }
      }

      resolve(returnObj);
    });

    return function (_x3, _x4) {
      return _ref.apply(this, arguments);
    };
  }());
}