"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _crypto = _interopRequireDefault(require("crypto"));

var _processOptions = require("./process-options");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function sourceNodes(_x, _x2) {
  return _sourceNodes.apply(this, arguments);
}

function _sourceNodes() {
  _sourceNodes = _asyncToGenerator(function* ({
    actions,
    createNodeId
  }, options) {
    delete options.plugins;

    function turnBreedImageIntoGatsbyNode(image) {
      const nodeId = createNodeId(`dog-image-${image.id}`);
      const nodeContent = JSON.stringify(image);

      const nodeContentDigest = _crypto.default.createHash("md5").update(nodeContent).digest("hex");

      const nodeData = _objectSpread({}, image, {
        id: nodeId,
        parent: null,
        children: [],
        internal: {
          type: "DogImage",
          content: nodeContent,
          contentDigest: nodeContentDigest
        }
      });

      return nodeData;
    } // Do the work


    const createNode = actions.createNode;
    const breedsResponse = yield (0, _processOptions.processBreedsOption)(options.breeds);

    if (breedsResponse.fetched) {
      // Create DogBreedList
      if (breedsResponse.list) {
        const nodeContent = JSON.stringify(breedsResponse.list);
        const nodeData = {
          list: breedsResponse.list,
          id: createNodeId("dog-breed-list-1"),
          parent: null,
          children: [],
          internal: {
            type: "DogBreedList",
            content: nodeContent,
            contentDigest: _crypto.default.createHash("md5").update(nodeContent).digest("hex")
          }
        };
        createNode(nodeData);
      } // Create DogImage


      breedsResponse.images.forEach(imgURL => {
        const imgObj = createImageObjectFromURL(imgURL);
        const nodeData = turnBreedImageIntoGatsbyNode(imgObj);
        createNode(nodeData);
      });
    }

    const breedResponse = yield (0, _processOptions.processBreedOption)(options.breed);

    if (breedResponse.fetched) {
      Object.entries(breedResponse.images).forEach(([name, images]) => {
        images.forEach(imgURL => {
          const imgObj = createImageObjectFromURL(imgURL);
          const nodeData = turnBreedImageIntoGatsbyNode(imgObj);
          createNode(nodeData);
        });
      });
    }

    return;
  });
  return _sourceNodes.apply(this, arguments);
}

function createImageObjectFromURL(url) {
  // url = https://images.dog.ceo/breeds/sheepdog-english/n02105641_13952.jpg
  const lastIndexOfSlash = url.lastIndexOf("/");
  const id = url.slice(lastIndexOfSlash + 1, url.lastIndexOf("."));
  const breedRecognizer = "breeds/";
  const breed = url.slice(url.indexOf(breedRecognizer) + breedRecognizer.length, lastIndexOfSlash).split("-").reverse().reduce((a, v) => `${a}${v.replace(/^\w/, c => c.toUpperCase())} `, "").trim();
  return {
    id,
    breed,
    url
  };
}

var _default = sourceNodes;
exports.default = _default;